@@ -61,30 +61,30 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"annotated.html",
-"globals_defs_p.html",
-"globals_k.html",
-"group__pw__context.html#ga528a327a97baf293d4765d0085719b91",
-"group__pw__impl__factory.html#ga81032931eb91354a197a6c1de9fff956",
-"group__pw__link.html#ga364b6ed143112bf432e1795503cc8e6e",
-"group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26",
-"group__pw__session__manager.html#ga8c6a1653431b3f9425a96aa0a6a72396",
-"group__spa__ansi.html#ga400ba03121c36fd42526652f8aa2842e",
-"group__spa__device.html#ga7caeded1f3eb1ff8ffce4cedd1b0b7c2",
-"group__spa__list.html#gaadec436f232586998917c75efeac05ab",
-"group__spa__node.html#gabb7d0304d2f9952bcf6b95041573c2a4",
-"group__spa__param.html#gac4e41d33f933cc70296e93f123d689d3",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcadf5297681fcd282838653ae2a8791130",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa877c930df72479fb16443effc07c6439",
-"group__spa__pod.html#ga5cac6d93f665bb39f005ed94a3b253e9",
-"group__spa__system.html#gad8592bcc0072a7f3e01c1c599c31a59a",
-"page_library.html#autotoc_md52",
-"structpw__client__methods.html#a2804d8a526c068a486a4e261821c9a07",
-"structpw__impl__metadata.html",
-"structpw__resource__events.html",
-"structspa__graph__node__callbacks.html#abc2bcb2b88b65f3eabe0e13d5d73f4e8",
-"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe",
-"structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74"
+"alloc_8h.html",
+"globals_defs_m.html",
+"globals_i.html",
+"group__pw__client__node.html#ga8f467593dff291edaac0f46531c23aed",
+"group__pw__impl__core.html#ga32f8301c7a43a4c4d418add1e71642a2",
+"group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0",
+"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47",
+"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
+"group__pwtest.html#gadf579902bf3375a739c90fe2aaf8fd89",
+"group__spa__debug.html#ga43da221712a4457ff34457555d39b214",
+"group__spa__keys.html#ga93f7f32803291d2334ff345690f7bc27",
+"group__spa__node.html#ga7345b7229cf2cf9e60cf142cd6c8c536",
+"group__spa__param.html#ga90558703b75bd503aab2fe68032bcccd",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca7de85ac83fa367961cfe400f7da4eb39",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa1a4e465f86a51b88d564e11faf6f5c65",
+"group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26",
+"group__spa__string.html",
+"iter_8h.html",
+"page_spa_pod.html#autotoc_md139",
+"structpw__endpoint__info.html#a1b2b450d001a613908596afb785c9bf6",
+"structpw__module.html",
+"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952",
+"structspa__io__sequence.html#ab6a424dad012da97efc02bfa77ed57d9",
+"structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
